import { NgModule } from '@angular/core';
import { Routes, RouterModule } from '@angular/router';
import { LoginComponent } from './components/login/login.component';
import { AuthActivateRouteGuard } from './routeguards/auth.routeguard';
import { HomeComponent } from './components/home/home.component';
import { FaqComponent } from './components/faq/faq.component';
import { OrderHomeComponent } from './components/order-home/order-home.component';
import { ActivateComponent } from './components/activate-account/activate.component';
import { AdminActivateRouteGuard } from './routeguards/admin.routeguard ';
import { ManageOrderComponent } from './components/order-home/manage-order/manage-order.component';
import { OrderDetailsResolverService } from './components/order-home/order-resolver.service';
import { ChairsAvailableOrdersComponent } from './components/order-home/chairs-available-orders/chairs-available-orders.component';
import { AllArchivedOrdersComponent } from './components/order-home/all-archived-orders/all-archived-orders.component';
import { AllAvailableOrdersComponent } from './components/order-home/all-available-orders/all-available-orders.component';
import { ChairsArchivedOrdersComponent } from './components/order-home/chairs-archived-orders/chairs-archived-orders.component';
import { UserInfoComponent } from './components/user/user-info/user-info.component';
import { UserRegistrationComponent } from './components/user/user-registration/user-registration.component';
import { OrderScanViewComponent } from './components/order-home/order-scan-view/order-scan-view.component';
import { ForgotPasswordComponent } from './components/forgot-password/forgot-password.component';
import { ForgotPasswordValidationComponent } from './components/forgot-password-validation/forgot-password-validation.component';
import { ArchivedOrderDetailsComponent } from './components/order-home/archived-order-details/archived-order-details.component';
import { UserManagementComponent } from './components/user/user-management/user-management.component';
import { StatisticsComponent } from './components/statistics/statistics.component';
import { AllInprogressOrdersComponent } from './components/order-home/all-inprogress-orders/all-inprogress-orders.component';
import { ChairsInprogressOrdersComponent } from './components/order-home/chairs-inprogress-orders/chairs-inprogress-orders.component';
import { MergePdfComponent } from './components/order-home/merge-pdf/merge-pdf.component';
import { ConfirmLeaveGuard } from './services/can-component-deactivate';
import { SearchComponent } from './components/search/search.component';


const routes: Routes = [
  { path: '', redirectTo: '/home', pathMatch: 'full'},
  { path: 'home', component: HomeComponent},
  { path: 'login', component: LoginComponent},
  { path: 'forgot-password', component: ForgotPasswordComponent },
  { path: 'preset', component: ForgotPasswordValidationComponent },
  { path: 'activate-account', component: ActivateComponent},
  // { path: 'contact', component: ContactComponent},
  { path: 'faq', component: FaqComponent},
  { path: 'orders', component: OrderHomeComponent, canActivate: [AuthActivateRouteGuard],
    children: [
      { path: 'available', component: ChairsAvailableOrdersComponent },
      { path: 'inprogress', component: ChairsInprogressOrdersComponent },
      { path: 'archived', component: ChairsArchivedOrdersComponent },
      { path: 'all-available', component: AllAvailableOrdersComponent },
      { path: 'all-inprogress', component: AllInprogressOrdersComponent },
      { path: 'all-archived', component: AllArchivedOrdersComponent },
      { path: '', redirectTo: 'available', pathMatch: 'full' }, // Default tab
    ],
  },
  { path: 'orders/manage/:orderId', component: ManageOrderComponent, canActivate: [AuthActivateRouteGuard], resolve: {resolvedOrderDetails: OrderDetailsResolverService} },
  { path: 'orders/archived/view/:orderId', component: ArchivedOrderDetailsComponent, canActivate: [AuthActivateRouteGuard], resolve: {resolvedOrderDetails: OrderDetailsResolverService} },
  { path: 'orders/scan/:orderId', component: OrderScanViewComponent, canActivate: [AuthActivateRouteGuard], canDeactivate: [ConfirmLeaveGuard],
     resolve: {resolvedOrderDetails: OrderDetailsResolverService} },
  { path: 'orders/scan/merge/:orderId', component: MergePdfComponent, canActivate: [AuthActivateRouteGuard], canDeactivate: [ConfirmLeaveGuard],
     resolve: {resolvedOrderDetails: OrderDetailsResolverService} }, 
  { path: 'account', canActivate: [AuthActivateRouteGuard],
    children: [
      { path: '', component: UserInfoComponent }, 
      { path: 'available', component: UserInfoComponent }, 
      { path: 'user-management', component: UserManagementComponent },
      { path: 'register', component: UserRegistrationComponent, canActivate: [AdminActivateRouteGuard] }
    ]
  },
  { path: 'statistics', component: StatisticsComponent, canActivate: [AdminActivateRouteGuard] },
  { path: 'search', component: SearchComponent, canActivate: [AuthActivateRouteGuard] },
  {path: '**', redirectTo: 'home'}
  //{path: '**', component: NotfoundComponent},
];

@NgModule({
  imports: [RouterModule.forRoot(routes)],
  exports: [RouterModule]
})
export class AppRoutingModule { }
