import { Component, Input, OnDestroy, OnInit } from '@angular/core';
import { ActivatedRoute, Router } from '@angular/router';
import { PDFDocumentProxy } from 'ng2-pdf-viewer';
import { Observable, Subscription, switchMap, tap } from 'rxjs';
import { LoadingService } from 'src/app/services/loading.service';
import { OrderResponseDto } from 'src/openapi/generated/models';
import { OrderService } from 'src/openapi/generated/services';
import { Location } from '@angular/common';

@Component({
  selector: 'app-archived-order-details',
  templateUrl: './archived-order-details.component.html',
  styleUrls: ['./archived-order-details.component.css']
})
export class ArchivedOrderDetailsComponent implements OnInit, OnDestroy {

  scannedPdf: Uint8Array | null = null;
  scannedPdfUrl: string;
  order: OrderResponseDto = {} as OrderResponseDto;
  //to display 1 page of a pdf document per time
  totalPagesPdf!: number;
  page: number = 1;
  isPdfError: boolean = false;
  isNow$: Observable<boolean>;
  subs: Subscription[] = [];


  constructor(
    private route: ActivatedRoute,
    private router: Router,
    private location: Location,
    private loadingService: LoadingService,
    private orderService: OrderService,
  ) { }

  ngOnInit(): void {
    this.subs.push(
      //get order from route
        this.route.data.pipe(
          tap(data => this.order = data['resolvedOrderDetails']),
          switchMap(() => this.orderService.getOrderPdf({ orderId: this.order.id, obsolete: false }))
        ).subscribe(
          //get scanned pdf to display
          pdf => {
            const reader = new FileReader();
            reader.onload = () => {
              const arrayBuffer = reader.result as ArrayBuffer;
              this.scannedPdf = new Uint8Array(arrayBuffer);
          //    const blob = new Blob([this.scannedPdf], { type: 'application/pdf' });
          //    this.scannedPdfUrl = URL.createObjectURL(blob);
            };
            reader.readAsArrayBuffer(pdf);
          }
        ));

  }

  goBack() {
    // if (window.history.length > 1) {
    //   this.location.back();
    // } else {
      this.router.navigate(['/orders/archived']);
    // }
  }
  
  //to display 1 page of a pdf document per time
  callBackFn(pdf: PDFDocumentProxy){
    this.totalPagesPdf = pdf.numPages;
    this.isPdfError = false;
    this.loadingService.isLoading.next(false);
  }

  onPdfError(error: any) {
    this.loadingService.isLoading.next(false);
    this.isPdfError = true;
  }

  nextPdfPage() {
    this.page++;
  }

  prevPdfPage() {
    this.page--;
  }

  goFirstPage() {
    this.page = 1;
  }

  goLastPage() {
    this.page = this.totalPagesPdf;
  }

  ngOnDestroy() {
    this.subs.forEach(sub => sub.unsubscribe());
  }

}

