import { OrderService } from 'src/openapi/generated/services';
import { Component, EventEmitter, Input, OnInit, Output } from '@angular/core';
import { PDFDocumentProxy } from 'ng2-pdf-viewer';
import { Observable } from 'rxjs';
import { TokenService } from 'src/app/services/token.service';
import { OrderResponseDto } from 'src/openapi/generated/models';

@Component({
  selector: 'app-order-card-archived',
  templateUrl: './order-card-archived.component.html',
  styleUrls: ['./order-card-archived.component.css']
})
export class OrderCardArchivedComponent implements OnInit{


/*********************** archived orders  *********************************/
  //actions
  @Output() view: EventEmitter<OrderResponseDto> = new EventEmitter<OrderResponseDto>();
  @Output() rescan: EventEmitter<OrderResponseDto> = new EventEmitter<OrderResponseDto>();
  @Output() scan: EventEmitter<OrderResponseDto> = new EventEmitter<OrderResponseDto>();
  @Input() order: OrderResponseDto;

  //to display 1 page of a pdf document per time
  totalPagesPdf!: number;
  page: number = 1;
  isPdfLoaded: boolean = false;
  isPdfError: boolean = false;
  isNow$: Observable<boolean>;
  scannedPdf: String;

  constructor(
     private orderService: OrderService
  ) { }

  ngOnInit(): void {
    this.orderService.getOrderPdf({orderId: this.order.id}).subscribe(
      data => {
        this.scannedPdf = URL.createObjectURL(data);
      }
    )
  }

  onView() {
    this.view.emit(this.order);
  }

  onRescan() {
    this.rescan.emit(this.order);
  }

  onScan() {
    this.scan.emit(this.order);
  }

  //to display 1 page of a pdf document per time
  callBackFn(pdf: PDFDocumentProxy){
    this.totalPagesPdf = pdf.numPages;
    this.isPdfLoaded = true;
    this.isPdfError = false;
  }

  onPdfError(error: any) {
    console.log(error);
    this.isPdfError = true;
  }

  nextPdfPage() {
    this.page++;
  }

  prevPdfPage() {
    this.page--;
  }

}
