import { OrderService } from './../../../openapi/generated/services/order.service';
import { Component, OnDestroy, OnInit } from '@angular/core';
import { Router, ActivatedRoute } from '@angular/router';
import { Subscription } from 'rxjs/internal/Subscription';
import { AlertService } from 'src/app/services/alert.service';
import { LoadingService } from 'src/app/services/loading.service';
import { TokenService } from 'src/app/services/token.service';
import { ManagementService } from 'src/openapi/generated/services/management.service';

@Component({
  selector: 'app-order-home',
  templateUrl: './order-home.component.html',
  styleUrls: ['./order-home.component.css']
})
export class OrderHomeComponent implements OnInit, OnDestroy {
  
  role = '';
  selectedTabIndex: number = 0;
  private subscriptions: Subscription[] = [];

  tabRoutes = [
    'available',
    'inprogress',
    'archived',
    'all-available',
    'all-inprogress',
    'all-archived',
  ];


  constructor(
    private loadingService: LoadingService,
    private alertService: AlertService,
    private managementService: ManagementService,
    private tokenService: TokenService,
    private router: Router,
    private route: ActivatedRoute
  ) {
  }

  ngOnInit() {
    this.subscriptions.push(
      this.tokenService.userAuthority$.subscribe(role => {
        this.role = role;
      })
    );

    // Listen for route changes to set active tab
    this.route.firstChild?.url.subscribe(() => {
      const activeTab = this.route.snapshot.firstChild?.url[0]?.path;
      this.selectedTabIndex = this.tabRoutes.indexOf(activeTab);
    });
  }


  onTabChange(event: any): void {
    this.selectedTabIndex = event.index;
    const targetRoute = this.tabRoutes[event.index];
    if (targetRoute) {
      this.router.navigate([targetRoute], { relativeTo: this.route });
    }
  }
  
  
  ngOnDestroy(): void {
    this.subscriptions.forEach(sub => sub.unsubscribe());
  }  
}
