import { Injectable, OnDestroy, OnInit } from '@angular/core';
import { ActivatedRouteSnapshot, Resolve, RouterStateSnapshot } from '@angular/router';
import { Observable, of, Subscription, switchMap } from 'rxjs';
import { TokenService } from 'src/app/services/token.service';
import { OrderResponseDto } from 'src/openapi/generated/models/order-response-dto';
import { AdminOrderService, ManagementService } from 'src/openapi/generated/services';
import { OrderService } from 'src/openapi/generated/services/order.service';

@Injectable({
  providedIn: 'root'
})
export class OrderDetailsResolverService implements Resolve<OrderResponseDto> {

  role = '';
  subscriptions: Subscription[] = [];

  constructor(
    private orderService: OrderService, 
    private adminOrderService: AdminOrderService, 
    private tokenService: TokenService,
    private managementService: ManagementService,
  ) { }

  resolve(route: ActivatedRouteSnapshot, state: RouterStateSnapshot): Observable<OrderResponseDto> | Promise<OrderResponseDto> | OrderResponseDto {
    this.initRole();
    this.subscriptions.forEach(sub => sub.unsubscribe());
    const orderId = route.params['orderId'];
    if(this.role == 'ROLE_USER') {
      return this.orderService.getChairsOrderByIdContaining({orderId: orderId}).pipe(
      switchMap((res) => {
        if(res.content.length > 0) {
          return of(res.content[0]);
        } else {
          return of(null);
        }
      })
    );
    } else if(this.role == 'ROLE_ADMIN') {
      return this.adminOrderService.getAnyOrderByIdContaining({orderId: orderId}).pipe(
        switchMap((res) => {
          if(res.content.length > 0) {
            return of(res.content[0]);
          } else {
            return of(null);
          }
        })
      );
    } else {
      throw new Error('No order found');
    }
  }

  initRole() {
    this.subscriptions.push(
      this.tokenService.userAuthority$.subscribe(role => {
        this.role = role;
      })
    );
  }


}
