import { ManagementService } from 'src/openapi/generated/services/management.service';
import { Injectable, OnDestroy, OnInit } from '@angular/core';
import { ActivatedRouteSnapshot, CanActivate, RouterStateSnapshot,Router } from '@angular/router';
import { TokenService } from '../services/token.service';
import { map, Observable, Subscription, take } from 'rxjs';

@Injectable()
export class AdminActivateRouteGuard implements CanActivate, OnDestroy {
    
    role: String = '';
    subs: Subscription[] = [];

    constructor(
        private tokenService: TokenService
    ){}

    canActivate(route:ActivatedRouteSnapshot, state:RouterStateSnapshot) : Observable<boolean> {
        return this.tokenService.userAuthority$.pipe(
            take(1), // Only take the first emitted value and complete the observable
            map(authority => {
              return authority == 'ROLE_ADMIN';
            })
          );
    }

    ngOnDestroy(): void {
        this.subs.forEach(sub => sub.unsubscribe());
    }
}