import { Injectable } from '@angular/core';
import { AlertType } from '../alert/alert-type.enum';
import { MatSnackBar, MatSnackBarConfig, MatSnackBarRef } from '@angular/material/snack-bar';
import { NotificationAlert, NotificationComponent } from '../alert/notification/notification.component';

@Injectable({
  providedIn: 'root'
})
export class AlertService {
  private notificationAlerts: NotificationAlert[] = [];
  private snackBarRef: MatSnackBarRef<NotificationComponent>;
  private snackBarIsDisplayed: boolean = false;

  constructor(private snackBar: MatSnackBar) { }

  showAlert(message: string, alertType: AlertType, duration: number = 5000): void {
    const alert = new NotificationAlert(message, alertType);
    this.notificationAlerts.push(alert);
    if (!this.snackBarIsDisplayed) {
        this.snackBarRef = this.snackBar.openFromComponent(NotificationComponent, {
            horizontalPosition: 'end',
            verticalPosition: 'top',
            data: {
                alerts: this.notificationAlerts,
                duration: duration,
            }
        });
        this.snackBarIsDisplayed = true;
    }
    setTimeout(() => this.snackBarRef.instance.removeAlert(alert), duration);

    this.snackBarRef.afterDismissed().subscribe(() => {
        this.snackBarIsDisplayed = false;
    });
  }
  
}
