import { Injectable, OnDestroy, OnInit } from '@angular/core';
import { Router } from '@angular/router';
// import { JwtHelperService } from '@auth0/angular-jwt/lib/jwthelper.service';
import { JwtHelperService } from '@auth0/angular-jwt';
import { error } from 'pdf-lib';
import { BehaviorSubject, Subscription } from 'rxjs';
import { ManagementService } from 'src/openapi/generated/services';

@Injectable({
  providedIn: 'root'
})
export class TokenService {

  private userAuthoritySubject = new BehaviorSubject<string>('');
  userAuthority$ = this.userAuthoritySubject.asObservable();
  redirectUrl: string;
  private readonly TOKEN_KEY = 'token';
  isLoggedInSubject: BehaviorSubject<boolean> = new BehaviorSubject<boolean>(false);
  editView: boolean = true;
  
  constructor(private router: Router,
    private managementService: ManagementService,
  ) { 
    // Listen for storage events from other tabs
    window.addEventListener('storage', (event) => {
      if (event.key === this.TOKEN_KEY) {
        if(!this.isLoggedInSubject.getValue()) {
          //if logged out in other tab, redirect also on this page to login
          this.router.navigateByUrl('/login');
        }
      }
    });

    //ORG
    //this.isTokenValid();
  }

  isTokenValid() {
    const jwtHelper = new JwtHelperService();
    try {
      //if token not available OR token has no valid username OR token is expired -> remove token and mark as invalid
      if (!this.token || !jwtHelper.decodeToken(this.token)?.sub || jwtHelper.isTokenExpired(this.token)) {
        this.removeToken();
        return;
      }
      const authorities: string = jwtHelper.decodeToken(this.token)?.authorities || [];
      if (authorities.length > 0) {
        this.userAuthoritySubject.next(authorities[0]);
      } else {
        this.fetchRole(); // Fetch from backend if token has no roles
      }
      this.isLoggedInSubject.next(true);
    } catch(error) {
      this.removeToken();
    }
  }

  private fetchRole() {
    this.managementService.getRole().subscribe({
      next: (role) => this.userAuthoritySubject.next(role),
      error: () => this.userAuthoritySubject.next(''),
    });
  }


  removeToken() {
    localStorage.removeItem(this.TOKEN_KEY);
    this.isLoggedInSubject.next(false);
    this.userAuthoritySubject.next('');
  }

  set token(token: string) {
    localStorage.setItem(this.TOKEN_KEY, token);
  }

  get token() {
    return localStorage.getItem(this.TOKEN_KEY) as string;
  }

  getEditView(): boolean {
    return this.editView;
  }

  setEditView(value: boolean) {
    this.editView = value;
  }

}
